<?php
/**
 * Zeros theme functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 */

/**
 * Theme setup
 */
function zeros_setup() {
	// Translation. Zeros is available for translations
	load_theme_textdomain( 'zeros', get_template_directory() . '/languages' );


	// Title tag manage by WordPress, not hardcoded
	add_theme_support( 'title-tag' );


	// Theme menus
	register_nav_menus( array(
	    'primary'   => __( 'Primary Menu', 'zeros' ),
	    'secondary' => __( 'Secondary Menu', 'zeros' ),
	    'legal'     => __( 'Legal Menu', 'zeros' )
	) );

	// Enable post thumbnails for posts
	add_theme_support( 'post-thumbnails' );

	// Enable HTML markup
	add_theme_support(
		'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		)
	);

	// Enable post formats
	add_theme_support(
		'post-formats', array(
			'video',
			'quote',
			'link',
			'gallery',
			'audio',
		)
	);

	// Enable custom logo
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	// Enable default RSS feed
	add_theme_support( 'automatic-feed-links' );

	// Enable support for editor styles.
	add_theme_support( 'editor-styles' );

	// Enqueue editor styles.
	add_editor_style( 'style-editor.css' );

	// Header image support
	$header_info = array(
	    'width'         => 1441,
	    'height'        => 305,
	    'default-image' => get_template_directory_uri() . '/assets/images/zeros-header-bg.jpg',
	);
	add_theme_support( 'custom-header', $header_info );

	// Default content width
	if ( ! isset( $content_width ) ) {
		$content_width = 600;
	}

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
add_action( 'after_setup_theme', 'zeros_setup' );


/**
 *  WordPress wp_body_open backward compatibility
**/
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}


/**
* Theme widgets initialization
*/
function zeros_widgets_init() {
	register_sidebar(
		array(
			'name'          => __( 'Blog Sidebar', 'zeros' ),
			'id'            => 'sidebar-1',
			'description'   => __( 'Blog and archive pages widget area.', 'zeros' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 1', 'zeros' ),
			'id'            => 'sidebar-2',
			'description'   => __( 'Footer first column widget area.', 'zeros' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 2', 'zeros' ),
			'id'            => 'sidebar-3',
			'description'   => __( 'Footer second column widget area.', 'zeros' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 3', 'zeros' ),
			'id'            => 'sidebar-4',
			'description'   => __( 'Footer three column widget area.', 'zeros' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'zeros_widgets_init' );

/**
 * Enqueue styles and script
 */
function zeros_scripts() {
	// Theme stylesheet.
	wp_enqueue_style( 'zeros-style', get_theme_file_uri( '/dist/styles/main.css' ) );

	$custom_css = zeros_theme_get_customizer_css();
  	wp_add_inline_style( 'zeros-style', $custom_css );

	wp_enqueue_script( 'zeros-main', get_theme_file_uri( '/dist/scripts/main.js' ), array( 'jquery' ), '1.0', true );

	wp_enqueue_script( 'zeros-wpb_togglemenu', get_theme_file_uri( '/dist/scripts/navigation.js' ), array('jquery'), '20160909', true );

	wp_enqueue_script( 'zeros-custom-modernizr', get_theme_file_uri( '/dist/scripts/modernizr-custom.js' ), array('jquery'), null, true );

	wp_enqueue_script( 'html5', get_theme_file_uri( '/assets/js/html5.js' ), array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'zeros_scripts' );

/**
 * Enqueue Google fonts
 */
function zeros_add_google_fonts() {
	wp_enqueue_style( 'zeros-google-fonts', 'https://fonts.googleapis.com/css?family=Saira:400,700|Open+Sans:300,300i,700,700i&subset=latin-ext' );
}
add_action( 'wp_enqueue_scripts', 'zeros_add_google_fonts' );


/**
 * Enqueue Dashicons 
 */
function zeros_load_dashicons(){
   wp_enqueue_style('dashicons');
}
add_action('wp_enqueue_scripts', 'zeros_load_dashicons', 999);

/**
* Excerpt
**/
function zeros_custom_excerpt_length( $length ) {
return 30;
}
add_filter( 'excerpt_length', 'zeros_custom_excerpt_length', 999 );


/**
* Theme customizations
**/
require get_parent_theme_file_path( '/inc/customizer.php' );
?>
