<?php
/**
 * The home page template
 *
 * @link https://codex.wordpress.org/Creating_a_Static_Front_Page
 *
 */
get_header();?>

<main role="main">
	<?php
	$class_modifier = is_front_page() ? 'frontpage-header' : '';
	$header_image   = get_header_image();
	$background     = '';

	if ( '' != $header_image && is_front_page() ) {
		$background = 'style="background-image: url('.$header_image.');"';
	}
	?>

	<header class="page-header <?php echo esc_attr($class_modifier); ?>" <?php echo $background; ?>>
		<div class="container">
			<?php if ( is_front_page() ) : ?>
				<div class="frontpage-header__title">
					<?php $tagline = get_bloginfo( 'description' );?>
					<p class="site-tag"><?php echo esc_html($tagline); ?></p>
					<h1 class="site-title"><?php echo esc_html( get_bloginfo( 'name' ) ); ?></h1>
				</div>
			<?php else: ?>
				<h1 class="page-title"><?php esc_html_e('Posts', 'zeros'); ?></h1>
			<?php endif; ?>
		</div>
	</header>

	<div class="container">
		<?php
		// Check if sidebar is active for blo
		$sidebar = get_theme_mod ('blog_sidebar', '');
		$colum_layout = '';
		if ( 1 == $sidebar) {
			$colum_layout = 'column column--large';
		}

		// Get selected layout
		$blog_layout = 'grid-layout';
		if ( 'classic' === get_theme_mod ('blog_layout', '')) {
			$blog_layout = 'classic-layout';
		}

		$final_classes = $blog_layout .' '. $colum_layout;
		?>
		<section class="main__content <?php echo esc_attr($final_classes); ?>">
			<div class="posts-wrapper">
			<?php if ( have_posts() ) : while ( have_posts() ) : the_post(); ?>
				<?php
					$format     = get_post_format();
					$thumbnail  = get_the_post_thumbnail_url();
					$background = '';
					$classes    = array('zeros-post');

					if ( '' != $thumbnail ) {
						$background = 'style="background-image: url('.get_the_post_thumbnail_url().'")';
					} elseif ( 'link' == $format ) {
						$classes[1] = 'zeros-post--link';
					} elseif ( 'quote' == $format ) {
						$classes[1] = 'zeros-post--quote';
					} elseif ( 'gallery' == $format ) {
						$classes[1] = 'zeros-post--gallery';
					} elseif ( 'video' == $format ) {
						$classes[1] = 'zeros-post--video';
					} elseif ( 'audio' == $format ) {
						$classes[1] = 'zeros-post--audio';
					} else {
						$classes[1] = 'zeros-post--default';
					}
				?>
    		
				<article <?php post_class( $classes ); ?> <?php if( 'grid-layout' == $blog_layout ) {echo $background; }?>>
					<div class="zeros-post__img" <?php echo $background; ?>></div>

	    			<div class="zeros-post__content">
						<div class="content-wrapper">
							<a href="<?php echo esc_url( get_permalink() ); ?>" class="full-width-link"></a>
							<h2><?php the_title(); ?></h2>
		    			<?php the_excerpt(); ?>
		    				<a href="<?php echo esc_url( get_permalink() ); ?>"><?php esc_html_e('Continue reading', 'zeros'); ?></a>
						</div>
	    			</div>

    			</article>
    		
			<?php endwhile; ?>
			</div>	
			
		  	<?php 
		  		// Posts navigation.
		  		$defaults = array(
		        	'next_text' => '<span class="meta-nav" aria-hidden="true">' . __( 'Next', 'zeros' ) . ': </span> ' .
		             	'<span class="screen-reader-text">' . __( 'Next post:', 'zeros' ) . '</span> ' .
		             	'<span class="post-title">%title</span>',
		        	'prev_text' => '<span class="meta-nav" aria-hidden="true">' . __( 'Previous', 'zeros' ) . ' :</span> ' .
		             	'<span class="screen-reader-text">' . __( 'Previous post:', 'zeros' ) . '</span> ' .
		            	'<span class="post-title">%title</span>',
		  		);	
			?>
		
			<?php the_posts_pagination(); ?>
		<?php else :
    		esc_html_e( 'Sorry, no posts matched your criteria.', 'zeros' );
		endif; ?>
		</section>

		<?php if (  1 == $sidebar ) {
			get_sidebar();
		}?>
	</div>

</main>

<?php get_footer(); ?>
