<?php
/**
 * Zeros: Customizer
**/

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function zeros_customize_register( $wp_customize ) {


	zeros_register_custom_sections($wp_customize);

	/**
	* Colors
	*/
	// Accent color
	$wp_customize-> add_setting(
		'accent_color', array(
			'default'   => '#008593',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize-> add_control(
		 new WP_Customize_Color_Control( $wp_customize,'accent_color', array(
			'label'    => __( 'Main color', 'zeros' ),
			'description' => __('Choose the main color for the page theme. It would be applied to links, the footer...', 'zeros'),
			'section'  => 'colors',
			'priority' => 1,
		))
	);

	// Secondary color
	$wp_customize-> add_setting(
		'secondary_color', array(
			'default'   => '#fffd2e',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize-> add_control(
		 new WP_Customize_Color_Control( $wp_customize,'secondary_color', array(
			'label'    => __( 'Secondary color', 'zeros' ),
			'description' => __('Choose the secondary color for the page theme. It would be use as accent color.', 'zeros'),
			'section'  => 'colors',
			'priority' => 1,
		))
	);

	// Background color
	$wp_customize-> add_setting(
		'theme_background_color', array(
			'default'   => '#fbfbfb',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize-> add_control(
		 new WP_Customize_Color_Control( $wp_customize,'theme_background_color', array(
			'label'    => __( 'Background color', 'zeros' ),
			'description' => __('Choose the color for the page background', 'zeros'),
			'section'  => 'colors',
			'priority' => 1,
		))
	);


	/**
	* Site header
	*/
	// Sticky header
	$wp_customize-> add_setting(
		'sticky_header', array(
			'default'   => 0,
			'sanitize_callback' => 'zeros_chkbox_sanitization',
		)
	);

	$wp_customize-> add_control(
		'sticky_header', array(
			'type'         => 'checkbox',
			'section'      => 'site_header',
			'label'    	   => __('Sticky header', 'zeros'),
			'description'  => __('Sticky header, both desktop and mobile', 'zeros'),
			'priority'     => 1
		)
	);

	// Disable top header
	$wp_customize-> add_setting(
		'disable_top_header', array(
			'default'   => 0,
			'sanitize_callback' => 'zeros_chkbox_sanitization',
		)
	);

	$wp_customize-> add_control(
		'disable_top_header', array(
			'type'         => 'checkbox',
			'section'      => 'site_header',
			'label'    	   => __('Disable top header', 'zeros'),
			'description'  => __('Check to disable top header', 'zeros'),
			'priority'     => 1
		)
	);

	// Top header text
	$wp_customize->add_setting(
		'header_top_text', array(
			'default'   => '',
			'sanitize_callback' => 'wp_kses_post',
		)
	);

	$wp_customize-> add_control(
		'header_top_text', array(
			'type'        => 'textarea',
			'section'     => 'site_header',
			'label'       => __('Top header text', 'zeros'),
			'description' => __('HTML is allowed. Use "p" tag for each pair label-value. Use "span" tag to delimiter labels.','zeros'),
		)
	);

	// Top header text color
	$wp_customize-> add_setting(
		'header_top_text_color', array(
			'default'   => '#fff',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize-> add_control(
		 new WP_Customize_Color_Control( $wp_customize,'header_top_text_color', array(
			'label'    => __( 'Top header text color', 'zeros' ),
			'section'  => 'site_header',
			'priority' => 2,
		))
	);

	// Menu items color
	$wp_customize-> add_setting(
		'menu_items_color', array(
			'default'   => '#333',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize-> add_control(
		 new WP_Customize_Color_Control( $wp_customize,'menu_items_color', array(
			'label'    => __( 'Menu items color', 'zeros' ),
			'section'  => 'site_header',
			'priority' => 2,
		))
	);

	// Mobile settings
	$wp_customize-> add_setting(
		'top_header_mobile', array(
			'default'   => 1,
			'sanitize_callback' => 'zeros_chkbox_sanitization',
		)
	);

	$wp_customize-> add_control(
		'top_header_mobile', array(
			'type'        => 'checkbox',
			'section'     => 'site_header',
			'label'       => __('Show top header on mobile', 'zeros'),
		)
	);

	/**
	* Content
	*/
	// Text color
	$wp_customize-> add_setting(
		'text_color', array(
			'default'   => '#787878',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize-> add_control(
		 new WP_Customize_Color_Control( $wp_customize,'text_color', array(
			'label'    => __( 'Text color', 'zeros' ),
			'section'  => 'content_page',
			'priority' => 2,
		))
	);

	// Headers color
	$wp_customize-> add_setting(
		'headers_color', array(
			'default'   => '#333',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize-> add_control(
		 new WP_Customize_Color_Control( $wp_customize,'headers_color', array(
			'label'    => __( 'Headers color', 'zeros' ),
			'section'  => 'content_page',
			'priority' => 3,
		))
	);

	// Sidebar
	$wp_customize-> add_setting(
		'content_sidebar', array(
			'default'   => 1,
		'sanitize_callback' => 'zeros_chkbox_sanitization',
		)
	);

	$wp_customize-> add_control(
		'content_sidebar', array(
			'type'        => 'checkbox',
			'section'     => 'content_page',
			'label'       => __('Enable sidebar on pages', 'zeros'),
		)
	);

	// Title background
	$wp_customize-> add_setting(
		'page_title_bg', array(
			'default'   => '#fff',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize-> add_control(
		 new WP_Customize_Color_Control( $wp_customize,'page_title_bg', array(
			'label'    => __( 'Page Title background color', 'zeros' ),
			'description' => __('Select the color for the static pages header', 'zeros'),
			'section'  => 'content_page',
			'priority' => 4,
		))
	);



	/**
	* Footer
	*/
	// Footer text colors
	$wp_customize-> add_setting(
		'footer_text_color', array(
			'default'   => '#fff',
			'sanitize_callback' => 'sanitize_hex_color',
		)

	);

	$wp_customize-> add_control(
		new WP_Customize_Color_Control( $wp_customize,'footer_text_color', array(
			'label'    => __( 'Footer text color', 'zeros' ),
			'section'  => 'footer_widgets',
			'priority' => 2,
		))
	);

	// Footer links colors
	$wp_customize-> add_setting(
		'footer_links_color', array(
			'default'   => '#fff',
			'sanitize_callback' => 'sanitize_hex_color',
		)

	);

	// Footer widgets
	$wp_customize-> add_setting(
		'footer_widget_counter', array(
	  		'default' => 'three',
	  		'sanitize_callback' => 'zeros_radio_sanitization',
	) );

	$wp_customize-> add_control(
		'footer_widget_counter', array(
	  		'type'        => 'radio',
	  		'section'     => 'footer_widgets',
	  		'label'       => __( 'Number of columns','zeros'),
	  		'description' => __( 'Select how many columns do you wish the footer widget are to have.', 'zeros'),
	  		'choices'     => array(
			    'one'   => __( 'One', 'zeros' ),
			    'two'   => __( 'Two', 'zeros' ),
			    'three' => __( 'Three', 'zeros' ),
	  		),
	  		'priority' => 1,
	) );

	$wp_customize-> add_control(
		new WP_Customize_Color_Control( $wp_customize,'footer_links_color', array(
			'label'    => __( 'Footer links color ', 'zeros' ),
			'section'  => 'footer_widgets',
			'priority' => 2,
		))
	);

	/**
	* Copyright bar
	*/
	// Copyright bar color
	$wp_customize-> add_setting(
		'copyright_color', array(
			'default'   => '#131313',
			'sanitize_callback' => 'sanitize_hex_color',
		)

	);

	$wp_customize-> add_control(
		new WP_Customize_Color_Control( $wp_customize,'copyright_color', array(
			'label'    => __( 'Copyright bar color', 'zeros' ),
			'section'  => 'copyright_bar',
			'priority' => 5,
		))
	);

	// Copyright text color
	$wp_customize-> add_setting(
		'copyright_text_color', array(
			'default'   => '#fbfbfb',
			'sanitize_callback' => 'sanitize_hex_color',
		)

	);

	$wp_customize-> add_control(
		new WP_Customize_Color_Control( $wp_customize,'copyright_text_color', array(
			'label'    => __( 'Copyright text color', 'zeros' ),
			'section'  => 'copyright_bar',
			'priority' => 5,
		))
	);

	// Copyright links color
	$wp_customize-> add_setting(
		'copyright_links_color', array(
			'default'   => '#fbfbfb',
			'sanitize_callback' => 'sanitize_hex_color',
		)

	);

	$wp_customize-> add_control(
		new WP_Customize_Color_Control( $wp_customize,'copyright_links_color', array(
			'label'    => __( 'Copyright links color', 'zeros' ),
			'section'  => 'copyright_bar',
			'priority' => 5,
		))
	);

	// Copyright bar text
	$wp_customize->add_setting(
		'copyright_text', array(
			'default'   => '<p>'. date('Y').' Zeros by <a href="http://www.juliamenndez.com" target="_blank">juliamenndez.com</a></p>',
			'sanitize_callback' => 'wp_kses_post',
		)
	);

	$wp_customize-> add_control(
		'copyright_text', array(
			'type'        => 'textarea',
			'section'     => 'copyright_bar',
			'label'       => __('Copyright bar text', 'zeros'),
			'description' => __('HTML is allowed.','zeros'),
		)
	);

	/**
	* Single post
	*/
	// Sidebar
	$wp_customize-> add_setting(
		'single_post_sidebar', array(
			'default'   => 1,
		'sanitize_callback' => 'zeros_chkbox_sanitization',
		)
	);

	$wp_customize-> add_control(
		'single_post_sidebar', array(
			'type'        => 'checkbox',
			'section'     => 'blog_pages',
			'label'       => __('Single post sidebar', 'zeros'),
			'description' => __('Enable sidebar for single posts', 'zeros'),
		)
	);


	// Featured image
	$wp_customize-> add_setting(
		'single_post_featured_img', array(
			'default'   => 1,
		'sanitize_callback' => 'zeros_chkbox_sanitization',
		)
	);

	$wp_customize-> add_control(
		'single_post_featured_img', array(
			'type'        => 'checkbox',
			'section'     => 'blog_pages',
			'label'       => __('Single post featured image', 'zeros'),
			'description' => __('Show featured image before post content in single posts', 'zeros'),
			'priority'    => 1
		)
	);


	/**
	* Blog pages
	*/
	// Blog layout
	$wp_customize-> add_setting(
		'blog_layout', array(
				'default' => 'grid',
				'sanitize_callback' => 'zeros_radio_sanitization',
	) );

	$wp_customize-> add_control(
		'blog_layout', array(
				'type'        => 'radio',
				'section'     => 'blog_pages',
				'label'       => __( 'Blog layout','zeros' ),
				'description' => __( 'Select the layout for blog page','zeros' ),
				'choices'     => array(
					'classic'    => __( 'Classic', 'zeros' ),
					'grid'  => __( 'Grid', 'zeros' ),
				),
				'priority' => 1,
	) );


	// Disable header image
	$wp_customize-> add_setting(
		'blog_header_image', array(
			'default'   => 1,
		'sanitize_callback' => 'zeros_chkbox_sanitization',
		)
	);

	$wp_customize-> add_control(
		'blog_header_image', array(
			'type'        => 'checkbox',
			'section'     => 'blog_pages',
			'label'       => __('Disable header image', 'zeros'),
			'description'       => __('Check to disable the image on post header', 'zeros'),
		)
	);

	// Blog sidebar
	$wp_customize-> add_setting(
		'blog_sidebar', array(
			'default'   => 1,
		'sanitize_callback' => 'zeros_chkbox_sanitization',
		)
	);

	$wp_customize-> add_control(
		'blog_sidebar', array(
			'type'        => 'checkbox',
			'section'     => 'blog_pages',
			'label'       => __('Blog sidebar', 'zeros'),
			'description'       => __('Enable sidebar for blog page', 'zeros'),
		)
	);	
}
add_action( 'customize_register', 'zeros_customize_register' );

function zeros_register_custom_sections( $wp_customize ) {
	// Site header section
	$wp_customize-> add_section('site_header', array(
		'title'    => __('ZEROS Site header', 'zeros'),
		'priority' => 130,
	));

	// Global content settings section
	$wp_customize-> add_section('content_page', array(
		'title'    => __('ZEROS Content', 'zeros'),
		'priority' => 140,
	));

	// Footer section
	$wp_customize-> add_section('footer_widgets', array(
		'title'    => __('ZEROS Footer', 'zeros'),
		'priority' => 150,
	));

	// Copyright bar section
	$wp_customize-> add_section('copyright_bar', array(
		'title'    => __('ZEROS Copyright bar', 'zeros'),
		'priority' => 160,
	));

	// Blog page section
	$wp_customize-> add_section('blog_pages', array(
		'title'    => __('ZEROS Blog', 'zeros'),
		'priority' => 180,
	));

}


/**
* Custom sanitization functions
*/
// Checkboxes
function zeros_chkbox_sanitization( $input ) {
   if ( true === $input ) {
      return 1;
   } else {
      return 0;
   }
}

// Radio buttons
function zeros_radio_sanitization( $input, $setting ){

    //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
    $input = sanitize_key($input);

    //get the list of possible radio box options
    $choices = $setting->manager->get_control( $setting->id )->choices;

    //return input if valid or return default option
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

}

// Images
function zeros_sanitize_file( $file, $setting ) {

    //allowed file types
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png'
    );

    //check file type from file name
    $file_ext = wp_check_filetype( $file, $mimes );

    //if file has a valid mime type return it, otherwise return default
    return ( $file_ext['ext'] ? $file : $setting->default );
}

function zeros_theme_get_customizer_css() {
    ob_start();

    $text_color                   = get_theme_mod( 'text_color', '' );
    $headers_color                = get_theme_mod( 'headers_color','' );
    $accent_color                 = get_theme_mod( 'accent_color', '' );
    $theme_background_color             = get_theme_mod( 'theme_background_color', '' );
    $secondary_color              = get_theme_mod( 'secondary_color', '' );
    $footer_text_color            = get_theme_mod( 'footer_text_color' );
    $footer_links_color           = get_theme_mod( 'footer_links_color' );
    $copyright_color              = get_theme_mod( 'copyright_color' );
    $copyright_text_color         = get_theme_mod( 'copyright_text_color' );
    $copyright_links_color        = get_theme_mod( 'copyright_links_color' );
    $top_header_text_color        = get_theme_mod( 'header_top_text_color' );
    $menu_items_color             = get_theme_mod( 'menu_items_color' );
	$single_post_images_alignment = get_theme_mod( 'single_post_images_alignment' );
	$page_title_bg                = get_theme_mod( 'page_title_bg');  
	$blog_header_image            = get_theme_mod( 'blog_header_image' );   

    if ( ! empty( $text_color ) ) {
		?>
		body p,
		body ul, 
		body ol,
		body dl,
		body table, 
		body address,
		body pre {
		color: <?php echo esc_attr($text_color); ?>;
		}
		<?php
    }

    if ( ! empty( $headers_color ) ) {
		?>
		main h1,
		main h2,
		main h3,
		main h4,
		main h5,
		main h6 {
		color: <?php echo esc_attr($headers_color); ?>;
		}
		<?php
    }

    if ( ! empty( $theme_background_color ) ) {
		?>
		main,
		#site-header {
		background-color: <?php echo esc_attr($theme_background_color); ?>;
		}

		<?php
    }

    if ( ! empty( $accent_color ) ) {
		?>
		main a,
		.site-name {
		color: <?php echo esc_attr($accent_color); ?>;
		}

		#top-header,
		#page-main-footer {
		background-color: <?php echo esc_attr($accent_color); ?>
		}

		button:not(.menu-toggle),
		input[type="submit"] {
			background-color: <?php echo esc_attr($accent_color); ?>
		}

		#main-header #menu-top .nav-menu.toggled-on,
		a {
			background-image: linear-gradient(transparent calc(100% - 1px), <?php echo esc_attr($accent_color); ?> 1px)
		}
		<?php
    }

    if ( ! empty( $secondary_color ) ) {
		?>
		#page-main-footer #footer-widgets-bar a:hover,
		#page-main-footer #footer-widgets-bar a:focus,
		#page-main-footer #footer-widgets-bar a:active {
		color: <?php echo esc_attr($secondary_color); ?>;
		}

		#top-header a:hover,
		#top-header a:focus,
		#top-header a:active {
		color: <?php echo esc_attr($secondary_color); ?>;
		}

		#page-main-footer #footer-widgets-bar a,
		#top-header a {
		background-image: linear-gradient(transparent calc(100% - 1px), <?php echo esc_attr($secondary_color); ?> 1px)
		}
		<?php
    }

    if ( ! empty( $footer_text_color ) ) {
		?>
		#page-main-footer,
		#page-main-footer ul {
		color: <?php echo esc_attr($footer_text_color); ?>;
		}
		<?php
    }

    if ( ! empty( $footer_links_color ) ) {
		?>
		#page-main-footer a,
		#page-main-footer #footer-widgets-bar a {
		color: <?php echo esc_attr($footer_links_color); ?>;
		}
	}
		<?php
    }

    if ( ! empty( $copyright_color ) ) {
		?>
		#page-main-footer #copyright-bar {
		background-color: <?php echo esc_attr($copyright_color); ?>;
		}
		<?php
    }

    if ( ! empty( $copyright_text_color ) ) {
		?>
		#page-main-footer #copyright-bar p {
		color: <?php echo esc_attr($copyright_text_color); ?>;
		}
		<?php
    }

    if ( ! empty( $copyright_links_color ) ) {
		?>
		#page-main-footer #copyright-bar p a {
		color: <?php echo esc_attr($copyright_links_color); ?>;
		background-image: linear-gradient(transparent calc(100% - 2px), <?php echo esc_attr($copyright_links_color); ?> 2px)
		}
		<?php
    }

    if ( ! empty( $top_header_text_color ) ) {
		?>
		#top-header p,
		#top-header p a {
		color: <?php echo esc_attr($top_header_text_color); ?>;
		}
		<?php
    }

    if ( ! empty( $menu_items_color ) ) {
		?>
		#main-header #menu-top .nav-menu > li > a {
		color: <?php echo esc_attr($menu_items_color); ?>;
		}
		<?php
    }


	if ( ! empty( $page_title_bg ) ) {
	?>
		.page-header {
		background-color: <?php echo esc_attr($page_title_bg); ?>;
		}
	<?php
	}
	

	if ( ! empty( $blog_header_image ) && $blog_header_image==1 ) {
	?>
		.post-header {
		    min-height: 10rem !important;
		    padding-bottom: 0 !important;
		}

		.post-header .curtain {
			display: none;
		}

		.post-header .post-title {
			color: #333;
		}

	<?php
	}
    

    $css = ob_get_clean();
    return $css;
  }
